@@ -1,7 +1,7 @@
 
 .onAttach <- function(libname, pkgname){
-	suppressWarnings(descr <- utils:::packageDescription("WeightedCluster"))
-	if(utils:::packageVersion("WeightedCluster")$minor %% 2 == 0) {
+	suppressWarnings(descr <- utils::packageDescription("WeightedCluster"))
+	if(utils::packageVersion("WeightedCluster")$minor %% 2 == 0) {
 		state <- "stable"
 	}
 	else {
@@ -15,7 +15,7 @@
 	packageStartupMessage("This is WeightedCluster ", state, " version ", descr$Version, builtDate)
 	packageStartupMessage('\nTo get the manuals, please run:')
 	packageStartupMessage('   vignette("WeightedCluster") ## Complete manual in English')
-	packageStartupMessage('   vignette("WeightedCluster-fr") ## Complete manual in French')
+	packageStartupMessage('   vignette("WeightedClusterFR") ## Complete manual in French')
 	packageStartupMessage('   vignette("WeightedClusterPreview") ## Short preview in English')
 	packageStartupMessage("\nTo cite WeightedCluster in publications please use:")
 	packageStartupMessage("Studer, Matthias (2013). WeightedCluster Library Manual: A practical guide to")
